@@ -20,12 +20,12 @@ class Function(ABC):
                 except Exception as e:
                     raise TypeError(f"Input {i} must be convertible to numpy array, got {type(inp)}") from e
         
-        # Apply autocast if enabled - simplified integration
+        # Apply autocast if enabled (but not for Cast operations to avoid recursion)
         try:
-            from neurograd.amp.autocast import autocast_tensor
+            from neurograd.amp.utils import maybe_cast_tensor
             op_name = getattr(self, 'name', None) or self.__class__.__name__
             if op_name != 'Cast':  # Avoid recursion with Cast operations
-                processed_inputs = [autocast_tensor(inp, op_name=op_name) for inp in processed_inputs]
+                processed_inputs = [maybe_cast_tensor(inp, op_name=op_name) for inp in processed_inputs]
         except ImportError:
             # AMP not available, continue with original precision
             pass
